==> haskell-monad-logger-0.3.31-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-logger
version: 0.3.31
id: monad-logger-0.3.31-7YU8gDZxquACgSGvZKbePy
key: monad-logger-0.3.31-7YU8gDZxquACgSGvZKbePy
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/monad-logger#readme
synopsis: A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>
category: System
abi: 5e94b99961d68ee852835daa96cfb010
exposed: True
exposed-modules:
    Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules: Paths_monad_logger
import-dirs: /usr/lib/ghc-8.6.5/site-local/monad-logger-0.3.31
library-dirs: /usr/lib/ghc-8.6.5/site-local/monad-logger-0.3.31
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/monad-logger-0.3.31
hs-libraries: HSmonad-logger-0.3.31-7YU8gDZxquACgSGvZKbePy
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-FcGmdT7SxdEGYrdumpBUzp
    conduit-extra-1.3.4-Cx6SL5PjCGfG7SKLduRPqb
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    fast-logger-3.0.0-5U3SuuA3S8r8Dz8F0S9pSI
    lifted-base-0.2.3.12-B4DztZYcWo5FX71P7R1jj6
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA mtl-2.2.2
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 stm-2.5.0.0
    stm-chans-3.0.0.4-HYjkOAxusm59Rsr7teGCcb template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock
haddock-html: /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-logger-0.3.31-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-logger
version: 0.3.31
id: monad-logger-0.3.31-7GuI6fn0wu46zyEORqvRSc
key: monad-logger-0.3.31-7GuI6fn0wu46zyEORqvRSc
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/monad-logger#readme
synopsis: A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>
category: System
abi: b90d15a956cbab8b3d1c8aded2563c30
exposed: True
exposed-modules:
    Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules: Paths_monad_logger
import-dirs: /usr/lib/ghc-8.6.5/site-local/monad-logger-0.3.31
library-dirs: /usr/lib/ghc-8.6.5/site-local/monad-logger-0.3.31
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/monad-logger-0.3.31
hs-libraries: HSmonad-logger-0.3.31-7GuI6fn0wu46zyEORqvRSc
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.2-E2wpiTRwNV9HimJJXCCytL
    conduit-extra-1.3.4-GvCdl1N4EKT6GVnxpJ4lQi
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    fast-logger-3.0.0-5U3SuuA3S8r8Dz8F0S9pSI
    lifted-base-0.2.3.12-B4DztZYcWo5FX71P7R1jj6
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA mtl-2.2.2
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 stm-2.5.0.0
    stm-chans-3.0.0.4-HYjkOAxusm59Rsr7teGCcb template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock
haddock-html: /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
